from flask import request
from marshmallow import Schema, fields, post_load, validate, validates, ValidationError
from app.devices.models import Device
class DeviceSchema(Schema):
    device_mac_address = fields.String(required=True, validate=validate.Length(max=255))
    device_name = fields.String(required=True)
    x_coordinate = fields.Float(required=False)
    y_coordinate = fields.Float(required=False)
    zone_id = fields.Integer(required=False)
    room_id = fields.Integer(required=False)
    patient_id = fields.Integer(required=False)
    user_id = fields.Integer(required=False)
    site_id =fields.Integer(required=False)
    device_type_id=fields.Integer(required=False)   
    device_type_name = fields.String(required=True)
    @validates("device_type_name")
    def required_device_type_name(self, value):
        if not value:
            raise ValidationError("The Device Type Name field is required")
    @validates("device_name")
    def required_device_name(self, value):
        if not value:
            raise ValidationError("The Device Name field is required")
    @validates("device_mac_address")
    def validates_device_mac_address(self, value):
        if not value:
            raise ValidationError("The Device Mac Address is required")
        if request.method == 'POST':
            existing_user = Device.query.filter_by(device_mac_address=value).first()
            if existing_user:
                raise ValidationError("Device Mac Address already exists")
    @post_load
    def make_user(self, data, **kwargs):
        return data
device_schema = DeviceSchema()